NSSALoss
========

.. currentmodule:: pykeen.losses

.. autoclass:: NSSALoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NSSALoss.hpo_default
      ~NSSALoss.synonyms

   .. rubric:: Methods Summary

   .. autosummary::

      ~NSSALoss.forward
      ~NSSALoss.process_lcwa_scores
      ~NSSALoss.process_slcwa_scores

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: synonyms

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
